==> epathmap-1.4.5-sources.jar: com/shitu/epathmap/ui/item/LocShareFriendItem.java <==
package com.shitu.epathmap.ui.item;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.shitu.epathmap.R;
import com.shitu.location.epathmap.model.bean.LocationRegionData;
import com.shitu.location.epathmap.utils.DateUtils;
import com.shitu.location.epathmap.utils.L;

public class LocShareFriendItem extends BaseRecyclerItemFactory<LocShareFriendItem.LocationShareFriendDataRecyclerItem> {

    Context context;
    private OnItemClickListener onItemNavClickListener;

    public LocShareFriendItem(Context context) {
        this.context = context;
    }

    public void setOnItemNavClickListener(OnItemClickListener onItemNavClickListener) {
        this.onItemNavClickListener = onItemNavClickListener;
    }

    @Override
    public boolean isTarget(Object itemObject) {
        return itemObject instanceof LocationRegionData;
    }

    @Override
    public LocationShareFriendDataRecyclerItem createBaseItem(ViewGroup parent) {
        return new LocationShareFriendDataRecyclerItem(parent, this);
    }

    public class LocationShareFriendDataRecyclerItem extends BaseRecyclerItem<LocationRegionData, LocShareFriendItem> {

        private RelativeLayout rlRoot;
        private TextView tvUserName, tvFloorName, tvUpdatedAt;
        private LinearLayout llNav;

        protected LocationShareFriendDataRecyclerItem(ViewGroup parent, LocShareFriendItem factory) {
            super(LayoutInflater.from(parent.getContext()).inflate(R.layout.ipsmap_item_loc_share_friends, parent, false), factory);
        }

        @Override
        protected void onFindViews(View convertView) {
            rlRoot = (RelativeLayout) convertView.findViewById(R.id.rl_root);
            tvFloorName = (TextView) convertView.findViewById(R.id.tv_floor_name);
            tvUserName = (TextView) convertView.findViewById(R.id.tv_user_name);
            tvUpdatedAt = (TextView) convertView.findViewById(R.id.tv_updatedAt);
            llNav = (LinearLayout) convertView.findViewById(R.id.ll_nav);
        }

        @Override
        protected void onConfigViews(final Context context) {
            if (onItemNavClickListener != null) {
                llNav.setOnClickListener(v -> onItemNavClickListener.onClick(getPosition()));
            }
            if (onItemClickListener != null) {
                rlRoot.setOnClickListener(v -> onItemClickListener.onClick(getPosition()));
            }
        }

        @Override
        protected void onSetData(int position, LocationRegionData item) {
            String buildingName = item.getBuildingName();
            String floorName = "";
            if (buildingName != null) {
                floorName += buildingName;
            }
            floorName += item.getFloorName() + "F";
            String userName = item.getName();
            if (item.isMe()) {
                userName += "(我的位置)";
            }
            if (item.getLatitude() == 0 && item.getLongitude() == 0) {
                floorName = context.getString(R.string.ipsmap_not_in_this_map);
            }
            tvUserName.setText(userName);
            tvFloorName.setText(floorName);
            tvUserName.setTextColor(context.getResources().getColor(R.color.ipsmap_tvBlack));
            tvFloorName.setTextColor(context.getResources().getColor(R.color.ipsmap_tvOrg1));
            String time = DateUtils.getTimeBeforeNow(item.getUpdatedAt().getTime());
            tvUpdatedAt.setText(time);
            tvUserName.setTextColor(context.getResources().getColor(R.color.ipsmap_tvGrey7));
            if (time.contains("分钟前")) {
                int pos = time.lastIndexOf("分钟前");
                String substring = time.substring(0, pos);
                try {
                    int lastMinute = Integer.parseInt(substring);
                    if (lastMinute >= 5) {
                        tvUserName.setTextColor(context.getResources().getColor(R.color.ipsmap_tvGrey));
                        tvFloorName.setTextColor(context.getResources().getColor(R.color.ipsmap_tvGrey));
                    }
                } catch (Exception e) {
                    L.e("ddd", e.toString());
                }
            } else if (time.contains("小时前")) {
                tvUserName.setTextColor(context.getResources().getColor(R.color.ipsmap_tvGrey));
                tvFloorName.setTextColor(context.getResources().getColor(R.color.ipsmap_tvGrey));
            }
            if (!item.isSelected()) {
                rlRoot.setBackgroundResource(R.color.ipsmap_white);
            } else {
                rlRoot.setBackgroundResource(R.color.ipsmap_tvGrey6);
            }
            if (!item.isMe()) {
                llNav.setVisibility(View.VISIBLE);
            } else {
                llNav.setVisibility(View.INVISIBLE);
            }
        }

    }


}

==> epathmap-1.7.2-sources.jar: com/shitu/epathmap/ui/item/LocShareFriendItem.java <==
package com.shitu.epathmap.ui.item;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.shitu.epathmap.R;
import com.shitu.location.epathmap.model.bean.LocationRegionData;
import com.shitu.location.epathmap.utils.DateUtils;
import com.shitu.location.epathmap.utils.L;

public class LocShareFriendItem extends BaseRecyclerItemFactory<LocShareFriendItem.LocationShareFriendDataRecyclerItem> {

    Context context;
    private OnItemClickListener onItemNavClickListener;

    public LocShareFriendItem(Context context) {
        this.context = context;
    }

    public void setOnItemNavClickListener(OnItemClickListener onItemNavClickListener) {
        this.onItemNavClickListener = onItemNavClickListener;
    }

    @Override
    public boolean isTarget(Object itemObject) {
        return itemObject instanceof LocationRegionData;
    }

    @Override
    public LocationShareFriendDataRecyclerItem createBaseItem(ViewGroup parent) {
        return new LocationShareFriendDataRecyclerItem(parent, this);
    }

    public class LocationShareFriendDataRecyclerItem extends BaseRecyclerItem<LocationRegionData, LocShareFriendItem> {

        private RelativeLayout rlRoot;
        private TextView tvUserName, tvFloorName, tvUpdatedAt;
        private LinearLayout llNav;

        protected LocationShareFriendDataRecyclerItem(ViewGroup parent, LocShareFriendItem factory) {
            super(LayoutInflater.from(parent.getContext()).inflate(R.layout.item_loc_share_friends, parent, false), factory);
        }

        @Override
        protected void onFindViews(View convertView) {
            rlRoot = (RelativeLayout) convertView.findViewById(R.id.rl_root);
            tvFloorName = (TextView) convertView.findViewById(R.id.tv_floor_name);
            tvUserName = (TextView) convertView.findViewById(R.id.tv_user_name);
            tvUpdatedAt = (TextView) convertView.findViewById(R.id.tv_updatedAt);
            llNav = (LinearLayout) convertView.findViewById(R.id.ll_nav);
        }

        @Override
        protected void onConfigViews(final Context context) {
            if (onItemNavClickListener != null) {
                llNav.setOnClickListener(v -> onItemNavClickListener.onClick(getPosition()));
            }
            if (onItemClickListener != null) {
                rlRoot.setOnClickListener(v -> onItemClickListener.onClick(getPosition()));
            }
        }

        @Override
        protected void onSetData(int position, LocationRegionData item) {
            String buildingName = item.getBuildingName();
            String floorName = "";
            if (buildingName != null) {
                floorName += buildingName;
            }
            floorName += item.getFloorName() + "F";
            String userName = item.getName();
            if (item.isMe()) {
                userName += "("+context.getString(R.string.epath_my_location)+")";
            }
            if (item.getLatitude() == 0 && item.getLongitude() == 0) {
                floorName = context.getString(R.string.epath_not_in_this_map);
            }
            tvUserName.setText(userName);
            tvFloorName.setText(floorName);
            tvUserName.setTextColor(context.getResources().getColor(R.color.tvBlack));
            tvFloorName.setTextColor(context.getResources().getColor(R.color.tvOrg1));
            String time = DateUtils.getTimeBeforeNow(item.getUpdatedAt().getTime());
            tvUpdatedAt.setText(time);
            tvUserName.setTextColor(context.getResources().getColor(R.color.tvGrey7));
            if (time.contains(context.getString(R.string.epath_minutes_ago))) {
                int pos = time.lastIndexOf(context.getString(R.string.epath_minutes_ago));
                String substring = time.substring(0, pos);
                try {
                    int lastMinute = Integer.parseInt(substring);
                    if (lastMinute >= 5) {
                        tvUserName.setTextColor(context.getResources().getColor(R.color.tvGrey));
                        tvFloorName.setTextColor(context.getResources().getColor(R.color.tvGrey));
                    }
                } catch (Exception e) {
                    L.e("ddd", e.toString());
                }
            } else if (time.contains(context.getString(R.string.epath_hours_ago))) {
                tvUserName.setTextColor(context.getResources().getColor(R.color.tvGrey));
                tvFloorName.setTextColor(context.getResources().getColor(R.color.tvGrey));
            }
            if (!item.isSelected()) {
                rlRoot.setBackgroundResource(R.color.white);
            } else {
                rlRoot.setBackgroundResource(R.color.tvGrey6);
            }
            if (!item.isMe()) {
                llNav.setVisibility(View.VISIBLE);
            } else {
                llNav.setVisibility(View.INVISIBLE);
            }
        }

    }


}
